# -*- coding: utf-8 -*-

"""
coingeckoapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

import json
import dateutil.parser

from tests.controllers.controller_test_base import ControllerTestBase
from tests.test_helper import TestHelper
from tests.http_response_catcher import HttpResponseCatcher
from coingeckoapiv3.api_helper import APIHelper
from coingeckoapiv3.controllers.events_controller import EventsController


class EventsControllerTests(ControllerTestBase):

    @classmethod
    def setUpClass(cls):
        super(EventsControllerTests, cls).setUpClass()
        cls.response_catcher = HttpResponseCatcher()
        cls.controller = EventsController(cls.config, cls.response_catcher)

    # Get events, paginated by 100
    #
    def test_getevents_paginatedby_100(self):
        # Parameters for the API call
        country_code = None
        mtype = None
        page = None
        upcoming_events_only = None
        from_date = None
        to_date = None

        # Perform the API call through the SDK function
        self.controller.getevents_paginatedby_100(country_code, mtype, page, upcoming_events_only, from_date, to_date)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)

    # Get list of event countries
    #
    def test_getlistofeventcountries(self):

        # Perform the API call through the SDK function
        self.controller.getlistofeventcountries()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)

    # Get list of event types
    #
    def test_getlistofeventstypes(self):

        # Perform the API call through the SDK function
        self.controller.getlistofeventstypes()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)

