# -*- coding: utf-8 -*-

"""
coingeckoapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

import json
import dateutil.parser

from tests.controllers.controller_test_base import ControllerTestBase
from tests.test_helper import TestHelper
from tests.http_response_catcher import HttpResponseCatcher
from coingeckoapiv3.api_helper import APIHelper
from coingeckoapiv3.controllers.status_updates_controller import StatusUpdatesController


class StatusUpdatesControllerTests(ControllerTestBase):

    @classmethod
    def setUpClass(cls):
        super(StatusUpdatesControllerTests, cls).setUpClass()
        cls.response_catcher = HttpResponseCatcher()
        cls.controller = StatusUpdatesController(cls.config, cls.response_catcher)

    # List all status_updates with data (description, category, created_at, user, user_title and pin)
    #
    def test_listallstatus_updateswithdata_description_category_created_at_user_user_titleandpin(self):
        # Parameters for the API call
        category = None
        project_type = None
        per_page = None
        page = None

        # Perform the API call through the SDK function
        self.controller.listallstatus_updateswithdata_description_category_created_at_user_user_titleandpin(category, project_type, per_page, page)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)

